@@ -1,73 +1,89 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2015-2019 Mike Fährmann
+# Copyright 2015-2021 Mike Fährmann
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
 # published by the Free Software Foundation.
 
 import re
-import importlib
 
 modules = [
     "2chan",
     "35photo",
     "3dbooru",
+    "420chan",
     "4chan",
     "500px",
+    "8kun",
     "8muses",
     "adultempire",
+    "architizer",
     "artstation",
+    "aryion",
+    "bbc",
+    "bcy",
     "behance",
     "blogger",
-    "bobx",
+    "comicvine",
+    "cyberdrop",
     "danbooru",
+    "desktopography",
     "deviantart",
     "dynastyscans",
     "e621",
-    "erolord",
+    "erome",
     "exhentai",
     "fallenangels",
+    "fanbox",
+    "fantia",
     "flickr",
+    "furaffinity",
     "fuskator",
     "gelbooru",
+    "gelbooru_v01",
+    "gelbooru_v02",
     "gfycat",
     "hbrowse",
     "hentai2read",
-    "hentaicafe",
+    "hentaicosplays",
     "hentaifoundry",
     "hentaifox",
+    "hentaihand",
     "hentaihere",
-    "hentainexus",
+    "hiperdex",
     "hitomi",
-    "hypnohub",
     "idolcomplex",
     "imagebam",
+    "imagechest",
     "imagefap",
     "imgbb",
     "imgbox",
     "imgth",
     "imgur",
+    "inkbunny",
     "instagram",
     "issuu",
+    "kabeuchi",
     "keenspot",
+    "kemonoparty",
     "khinsider",
-    "kissmanga",
     "komikcast",
-    "konachan",
     "lineblog",
     "livedoor",
     "luscious",
     "mangadex",
     "mangafox",
     "mangahere",
-    "mangapanda",
+    "mangakakalot",
+    "manganelo",
     "mangapark",
-    "mangareader",
-    "mangastream",
+    "mangasee",
     "mangoxo",
+    "myhentaigallery",
     "myportfolio",
     "naver",
+    "naverwebtoon",
     "newgrounds",
     "ngomik",
     "nhentai",
@@ -76,8 +92,12 @@ modules = [
     "nsfwalbum",
     "paheal",
     "patreon",
+    "philomena",
     "photobucket",
+    "photovogue",
+    "picarto",
     "piczel",
+    "pillowfort",
     "pinterest",
     "pixiv",
     "pixnet",
@@ -87,31 +107,40 @@ modules = [
     "reactor",
     "readcomiconline",
     "reddit",
-    "rule34",
-    "safebooru",
+    "redgifs",
     "sankaku",
     "sankakucomplex",
     "seiga",
+    "seisoparty",
     "senmanga",
     "sexcom",
     "simplyhentai",
+    "skeb",
     "slickpic",
     "slideshare",
     "smugmug",
+    "speakerdeck",
+    "subscribestar",
+    "tapas",
     "tsumino",
     "tumblr",
+    "tumblrgallery",
     "twitter",
+    "unsplash",
     "vanillarock",
+    "vk",
     "vsco",
     "wallhaven",
     "warosu",
+    "weasyl",
+    "webtoons",
     "weibo",
     "wikiart",
+    "wikieat",
     "xhamster",
     "xvideos",
-    "yandere",
-    "yaplog",
-    "yuki",
+    "booru",
+    "moebooru",
     "foolfuuka",
     "foolslide",
     "mastodon",
@@ -121,6 +150,7 @@ modules = [
     "recursive",
     "oauth",
     "test",
+    "ytdl",
 ]
 
 
@@ -128,7 +158,7 @@ def find(url):
     """Find a suitable extractor for the given URL"""
     for cls in _list_classes():
         match = cls.pattern.match(url)
-        if match and cls not in _blacklist:
+        if match:
             return cls(match)
     return None
 
@@ -157,26 +187,10 @@ def extractors():
     )
 
 
-class blacklist():
-    """Context Manager to blacklist extractor modules"""
-    def __init__(self, categories, extractors=None):
-        self.extractors = extractors or []
-        for cls in _list_classes():
-            if cls.category in categories:
-                self.extractors.append(cls)
-
-    def __enter__(self):
-        _blacklist.update(self.extractors)
-
-    def __exit__(self, etype, value, traceback):
-        _blacklist.clear()
-
-
 # --------------------------------------------------------------------
 # internals
 
 _cache = []
-_blacklist = set()
 _module_iter = iter(modules)
 
 
@@ -184,10 +198,13 @@ def _list_classes():
     """Yield all available extractor classes"""
     yield from _cache
 
+    globals_ = globals()
     for module_name in _module_iter:
-        module = importlib.import_module("."+module_name, __package__)
+        module = __import__(module_name, globals_, None, (), 1)
         yield from add_module(module)
 
+    globals_["_list_classes"] = lambda : _cache
+
 
 def _get_classes(module):
     """Return a list of all extractor classes in a module"""
